==> theme-bootstrap-2.0.16.tgz: package/src/components/refill-balance/choose-payment/choose-payment.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import { IconEthLogo } from '../../icons/icon-eth-logo/icon-eth-logo';
import { IconCreditCards } from '../../icons/icon-credit-cards/icon-credit-cards';

import GA from '../../../helpers/ga';

import './choose-payment.scss';

export class ChoosePayment extends Component {
  static propTypes = {
    onEthClick: PropTypes.func.isRequired,
  };

  state = {
    isShow: false,
  };

  onEthClick = () => {
    GA.event({ category: 'BuySCR', action: '2Choose eth' });
    this.props.onEthClick();
  };

  onFiatClick = () => {
    GA.event({ category: 'BuySCR', action: '2Choose fiat' });
    this.setState({ isShow: true });
  };

  render() {
    const { isShow } = this.state;

    return (
      <div className="choose-payment text-center">
        <h3 className="mb-2">
          <FormattedMessage id="universal.balance.refill.choose-payment-step.title" />
        </h3>

        <FormattedMessage id="universal.balance.refill.choose-payment-step.subtitle" />

        <div
          className="step mt-4_5 mb-2 d-flex justify-content-center align-items-center border border-shade-s30 rounded"
          role="button"
          tabIndex="0"
          onClick={this.onEthClick}
          onKeyPress={this.onEthClick}
        >
          <IconEthLogo />
        </div>

        <div
          className="step d-flex justify-content-center align-items-center border border-shade-s30 rounded"
          role="button"
          tabIndex="0"
          onClick={this.onFiatClick}
          onKeyPress={this.onFiatClick}
        >
          <IconCreditCards />
        </div>

        {isShow && (
          <div className="mt-1_5">
            <FormattedMessage id="universal.balance.refill.choose-payment-step.not-available" />
          </div>
        )}
      </div>
    );
  }
}

==> theme-bootstrap-2.0.28.tgz: package/src/components/refill-balance/choose-payment/choose-payment.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';

import { IconEthLogo } from '../../icons/icon-eth-logo/icon-eth-logo';
import { IconCreditCards } from '../../icons/icon-credit-cards/icon-credit-cards';

import GA from '../../../helpers/ga';

import './choose-payment.scss';

export class ChoosePayment extends Component {
  static propTypes = {
    onEthClick: PropTypes.func.isRequired,
    isEthLogoWhite: PropTypes.bool,
  };

  static defaultProps = {
    isEthLogoWhite: true,
  }

  state = {
    isShow: false,
  };

  onEthClick = () => {
    GA.event({ category: 'BuySCR', action: '2Choose eth' });
    this.props.onEthClick();
  };

  onFiatClick = () => {
    GA.event({ category: 'BuySCR', action: '2Choose fiat' });
    this.setState({ isShow: true });
  };

  render() {
    const { isEthLogoWhite } = this.props;
    const { isShow } = this.state;

    return (
      <div className="choose-payment text-center">
        <h3 className="mb-2">
          <FormattedMessage id="universal.balance.refill.choose-payment-step.title" />
        </h3>

        <FormattedMessage id="universal.balance.refill.choose-payment-step.subtitle" />

        <div
          className="step mt-4_5 mb-2 d-flex justify-content-center align-items-center border converter-border rounded"
          role="button"
          tabIndex="0"
          onClick={this.onEthClick}
          onKeyPress={this.onEthClick}
        >
          <IconEthLogo isWhite={isEthLogoWhite} />
        </div>

        <div
          className="step d-flex justify-content-center align-items-center border converter-border rounded"
          role="button"
          tabIndex="0"
          onClick={this.onFiatClick}
          onKeyPress={this.onFiatClick}
        >
          <IconCreditCards />
        </div>

        {isShow && (
          <div className="mt-1_5">
            <FormattedMessage id="universal.balance.refill.choose-payment-step.not-available" />
          </div>
        )}
      </div>
    );
  }
}
